﻿using System;
using System.Collections.Generic;

// Interface for workflow stages
interface IWorkflowStage
{
    void Execute();
}

// Concrete workflow stages
class StageA : IWorkflowStage
{
    public void Execute()
    {
        Console.WriteLine("Executing Stage A");
        // Perform stage A logic
    }
}

class StageB : IWorkflowStage
{
    public void Execute()
    {
        Console.WriteLine("Executing Stage B");
        // Perform stage B logic
    }
}

class StageC : IWorkflowStage
{
    public void Execute()
    {
        Console.WriteLine("Executing Stage C");
        // Perform stage C logic
    }
}

// Workflow pipeline
class WorkflowPipeline
{
    private List<IWorkflowStage> stages;

    public WorkflowPipeline()
    {
        stages = new List<IWorkflowStage>();
    }

    public void AddStage(IWorkflowStage stage)
    {
        stages.Add(stage);
    }

    public void Execute()
    {
        foreach (IWorkflowStage stage in stages)
        {
            stage.Execute();
        }
    }
}

class WorkflowPipelineMain
{
    static void Main(string[] args)
    {
        // Create workflow stages
        IWorkflowStage stageA = new StageA();
        IWorkflowStage stageB = new StageB();
        IWorkflowStage stageC = new StageC();

        // Create a workflow pipeline
        WorkflowPipeline workflowPipeline = new WorkflowPipeline();
        workflowPipeline.AddStage(stageA);
        workflowPipeline.AddStage(stageB);
        workflowPipeline.AddStage(stageC);

        // Execute the workflow pipeline
        workflowPipeline.Execute();

        // No need for explicit memory cleanup in C# (garbage collection will handle it)
    }
}
